# Create your models here.
import decimal

from django.contrib.postgres.fields import ArrayField
from django.db import models

from .. import model_settings


class PaymentMethodSummary(models.Model):
    """Dump payment methods to the data warehouse."""

    last_synced = models.DateTimeField()
    customer_account_number = models.CharField(max_length=50)
    gocardless_id = models.CharField(max_length=100)
    stripe_id = models.CharField(max_length=100)
    description = models.CharField(max_length=250, blank=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = 'subscriptionmanager'

        default_permissions = ()
        db_table = 'subscriptionmanager"."billing_paymentmethod_summary'



class RevenueForecastSummary(models.Model):
    """Dump payment methods to the data warehouse."""

    last_synced = models.DateTimeField()
    month = models.DateField()
    total_contract_value = models.DecimalField(max_digits=10, decimal_places=2)
    total_credit_value = models.DecimalField(max_digits=10, decimal_places=2)
    signed_value = models.DecimalField(max_digits=10, decimal_places=2)
    starting_value = models.DecimalField(max_digits=10, decimal_places=2)
    subs_total = models.IntegerField()
    subs_total_paying = models.IntegerField()
    subs_starting = models.IntegerField()
    subs_won = models.IntegerField()
    subs_lost = models.IntegerField()

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = 'subscriptionmanager'

        default_permissions = ()
        db_table = 'subscriptionmanager"."billing_revenueforecast_summary'



class SubscriptionSummary(models.Model):
    """Dump data to the data warehouse so that it can be used by other reporting or internal tools like Vitally."""

    last_synced = models.DateTimeField()

    created = models.DateTimeField()
    updated = models.DateTimeField()
    salesperson = models.CharField(max_length=200)
    product = models.CharField(max_length=200)

    # customer details
    customer_name = models.CharField(max_length=200)
    customer_account_number = models.CharField(max_length=50, unique=True)
    customer_xero_guid = models.UUIDField(blank=True)
    customer_primary_contact_name = models.CharField(max_length=200)
    customer_primary_contact_email = models.CharField(max_length=200)
    customer_accounts_contact_name = models.CharField(max_length=200)
    customer_accounts_contact_email = models.CharField(max_length=200)
    customer_company_tax_number = models.CharField(max_length=50, help_text="ABN, NZBN or VAT number.")

    # subscriptions
    subscription_guid = models.UUIDField()
    currency = models.CharField(max_length=3)
    signing_date = models.DateField()
    billing_date = models.DateField()

    plan = models.CharField(max_length=100)
    staff_addon_name = models.CharField(max_length=100)

    plan_included_licenses = models.IntegerField(blank=True, null=True)
    additional_committed_staff = models.IntegerField(blank=True, null=True)
    total_contracted_staff_licenses = models.IntegerField(blank=True, null=True)

    override_plan_price = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)
    override_staff_price = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)

    effective_discount = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)
    total_contract_price = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)

    # addons
    hosting_addon_price = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)
    bi_addon_price = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)
    sla_addon_price = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)

    # workspaces
    workspaces = ArrayField(models.CharField(max_length=50), default=list, blank=True)

    # termination
    termination_date = models.DateField(blank=True, null=True)
    termination_code = models.TextField(blank=True)
    termination_reason = models.TextField(blank=True)

    # current usage data
    current_expansion_chargeable = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)
    current_total_mrr_chargeable = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)
    current_total_used_staff_licenses = models.IntegerField(blank=True, null=True)
    current_total_additional_chargable_licenses = models.IntegerField(blank=True, null=True)
    current_monthly_recurring_credit = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)

    # last month usage data
    lastmonth_expansion_charged = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)
    lastmonth_total_mrr_charged = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)
    lastmonth_total_used_staff_licenses = models.IntegerField(blank=True, null=True)
    lastmonth_total_used_desk_licenses = models.IntegerField(blank=True, null=True)
    lastmonth_total_used_field_licenses = models.IntegerField(blank=True, null=True)
    lastmonth_total_additional_chargable_licenses = models.IntegerField(blank=True, null=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = 'subscriptionmanager'

        default_permissions = ()
        db_table = 'subscriptionmanager"."billing_subscription_summary'


class RecurringCreditSummary(models.Model):
    """Dump data to the data warehouse so that it can be used by other reporting or internal tools like Vitally."""

    last_synced = models.DateTimeField()

    subscription_guid = models.UUIDField()
    customer_name = models.CharField(max_length=200)
    customer_account_number = models.CharField(max_length=50, unique=True)
    currency = models.CharField(max_length=3)

    start_date = models.DateField()
    review_date = models.DateField(blank=True, null=True)
    expiry_date = models.DateField()
    amount = models.DecimalField(max_digits=10, decimal_places=2)
    invoice_text = models.CharField(max_length=200)
    internal_note = models.CharField(max_length=500, blank=True)
    credit_classification = models.TextField()

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = 'subscriptionmanager'

        default_permissions = ()
        db_table = 'subscriptionmanager"."billing_recurring_credit_summary'


class ChangeSummary(models.Model):
    """Dump data to the data warehouse so that it can be used by other reporting or internal tools like Vitally."""

    last_synced = models.DateTimeField()

    subscription_guid = models.UUIDField()
    customer_name = models.CharField(max_length=200)
    customer_account_number = models.CharField(max_length=50, unique=True)
    currency = models.CharField(max_length=3)

    change_type = models.TextField()
    date = models.DateField()
    note = models.TextField(blank=True)
    amount = models.DecimalField(max_digits=10, decimal_places=2)
    salesperson = models.CharField(max_length=200)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = 'subscriptionmanager'

        default_permissions = ()
        db_table = 'subscriptionmanager"."billing_change_summary'


class ChargeSummary(models.Model):
    """Dump data to the data warehouse so that it can be used by other reporting or internal tools like Vitally."""

    last_synced = models.DateTimeField()

    created = models.DateTimeField()
    updated = models.DateTimeField()
    requestor = models.CharField(max_length=200)

    subscription_guid = models.UUIDField()
    customer_name = models.CharField(max_length=200)
    customer_account_number = models.CharField(max_length=50, unique=True)
    currency = models.CharField(max_length=3)

    itemcode = models.CharField(max_length=20)
    description = models.CharField(max_length=500)
    account_code = models.CharField(max_length=20)
    quantity = models.DecimalField(max_digits=10, decimal_places=2)
    amount = models.DecimalField(max_digits=10, decimal_places=2)
    tracking_category_1 = models.CharField(max_length=50)
    tracking_category_2 = models.CharField(max_length=50)
    subtotal = models.DecimalField(max_digits=10, decimal_places=2)
    total = models.DecimalField(max_digits=10, decimal_places=2)

    invoice_date = models.DateField(null=True)
    invoice_reference = models.CharField(null=True, max_length=20)
    invoice_number = models.CharField(null=True, max_length=20)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = 'subscriptionmanager'

        default_permissions = ()
        db_table = 'subscriptionmanager"."billing_charge_summary'


class WorkspaceSummary(models.Model):
    """Dump data to the data warehouse so that any other tools can map workspaces back to customers and subscriptions.
    """

    last_synced = models.DateTimeField()

    guid = models.UUIDField(primary_key=True)
    name = models.CharField(max_length=50, unique=True)
    customer_account_number = models.CharField(max_length=50, unique=True)
    subscription_guid = models.UUIDField()

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = 'subscriptionmanager'

        default_permissions = ()
        db_table = 'subscriptionmanager"."billing_workspace_summary'


class XeroContactSummary(models.Model):
    """Dump data to the data warehouse so that it can be used by other reporting or internal tools like Vitaly."""

    last_synced = models.DateTimeField()

    customer_name = models.CharField(max_length=200)
    customer_account_number = models.CharField(max_length=50)
    customer_first_name = models.CharField(max_length=100)
    customer_last_name = models.CharField(max_length=100)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = 'subscriptionmanager'

        default_permissions = ()
        db_table = 'subscriptionmanager"."billing_xero_customer_summary'


class XeroInvoiceSummary(models.Model):
    """Dump data to the data warehouse so that it can be used by other reporting or internal tools like Vitaly."""

    last_synced = models.DateTimeField()

    invoice_guid = models.UUIDField()
    contact_guid = models.UUIDField()
    contact_name = models.CharField(max_length=200)
    contact_account_number = models.CharField(max_length=50)
    number = models.CharField(max_length=50)
    reference = models.CharField(max_length=100)
    date = models.DateField(blank=True, null=True)
    due_date = models.DateField(blank=True, null=True)
    subtotal = models.DecimalField(max_digits=10, decimal_places=2, default=decimal.Decimal("0.00"))
    total = models.DecimalField(max_digits=10, decimal_places=2, default=decimal.Decimal("0.00"))
    status = models.CharField(max_length=50)
    currency = models.CharField(max_length=3)
    currency_rate = models.DecimalField(max_digits=10, decimal_places=2, default=decimal.Decimal("0.00"))
    is_sent = models.BooleanField()
    repeating_invoice_guid = models.UUIDField()
    amount_due = models.DecimalField(max_digits=10, decimal_places=2, default=decimal.Decimal("0.00"))
    amount_paid = models.DecimalField(max_digits=10, decimal_places=2, default=decimal.Decimal("0.00"))
    fully_paid_on_date = models.DateField(blank=True, null=True)

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = 'subscriptionmanager'

        default_permissions = ()
        db_table = 'subscriptionmanager"."billing_xero_invoice_summary'


class ServerUsage(models.Model):
    """Resource usage.

    This is an unmanaged model that lets us easily grab the resources used by the customer
    for the current billing cycle.

    TODO not sure where this belongs.
    """

    tenant = models.CharField(max_length=200, primary_key=True)
    staff_licenses_total = models.IntegerField()
    staff_licenses_used = models.IntegerField()  # This is all we're using currently
    staff_licenses_additional = models.IntegerField()
    desk_licenses_used = models.IntegerField()
    field_licenses_used = models.IntegerField()
    contractor_licenses_used = models.IntegerField()
    customer_licenses_used = models.IntegerField()
    api_licenses_used = models.IntegerField()
    reporting_licenses_used = models.IntegerField()
    timesheet_licenses_used = models.IntegerField()
    last_synced = models.DateTimeField()
    for_date = models.DateField()

    class Meta:
        managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
        app_label = 'subscriptionmanager'

        default_permissions = ()
        db_table = 'subscriptionmanager"."licensing_usage'



# Generated by Django 4.1.5 on 2023-01-12 03:25

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("workforce", "0001_schema"),
    ]

    operations = [
        migrations.CreateModel(
            name="ConstanceSetting",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("slug", models.CharField(max_length=100)),
                ("setting_name", models.TextField()),
                ("setting_value", models.TextField()),
                ("last_reported", models.DateTimeField()),
            ],
            options={
                "db_table": 'workforce"."constance_summary',
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="ExtensionSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("name", models.CharField(max_length=100, unique=True)),
                ("is_enabled", models.BooleanField(db_index=True)),
            ],
            options={
                "db_table": 'workforce"."extension_summary',
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="FeatureFlagSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("name", models.CharField(max_length=100, unique=True)),
                ("is_enabled", models.BooleanField(db_index=True)),
            ],
            options={
                "db_table": 'workforce"."featureflag_summary',
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="OnboardingActionRow",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("last_synced", models.DateTimeField(db_index=True)),
                ("is_active", models.BooleanField(db_index=True)),
                ("name", models.CharField(max_length=150)),
                ("description", models.TextField(blank=True, default="")),
                ("due_date", models.DateField(blank=True, null=True)),
                ("completed_date", models.DateField(blank=True, null=True)),
                ("responsibility", models.CharField(max_length=100)),
                (
                    "assigned_to",
                    models.CharField(blank=True, default="", max_length=100),
                ),
                ("progress", models.IntegerField(blank=True, null=True)),
                ("effort", models.IntegerField(blank=True, null=True)),
                ("group", models.CharField(max_length=100)),
            ],
            options={
                "db_table": 'workforce"."customer_onboarding_actions',
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="TemplateChangeRequestSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("tcr_pk", models.PositiveIntegerField()),
                ("created", models.DateTimeField()),
                ("currency", models.CharField(blank=True, max_length=3, null=True)),
                (
                    "requested_changes",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(max_length=100),
                        blank=True,
                        default=list,
                        size=None,
                        verbose_name="Requested modifications",
                    ),
                ),
                ("status", models.CharField(db_index=True, max_length=20)),
                ("status_changed_requested", models.DateTimeField()),
                ("status_changed_approved", models.DateTimeField()),
                ("status_changed_completed", models.DateTimeField()),
                ("template_key", models.CharField(max_length=200)),
                ("template_name", models.CharField(max_length=200)),
                ("template_content_type_model", models.CharField(max_length=200)),
                ("estimated_price", models.PositiveIntegerField()),
                (
                    "estimated_hours",
                    models.DecimalField(decimal_places=4, max_digits=11),
                ),
            ],
            options={
                "db_table": 'workforce"."templates_template_change_request_summary',
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="UsageMetrics",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("count_name", models.CharField(db_index=True, max_length=200)),
                ("stat_count", models.BigIntegerField()),
                ("as_of", models.DateTimeField(db_index=True)),
            ],
            options={
                "db_table": 'workforce"."usage_metrics',
            },
        ),
        migrations.CreateModel(
            name="UserSummaryRow",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("last_synced", models.DateTimeField(db_index=True)),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("user_pk", models.PositiveIntegerField(db_index=True)),
                ("email", models.CharField(db_index=True, max_length=255)),
                ("name", models.CharField(max_length=255)),
                ("license", models.CharField(db_index=True, max_length=10)),
                ("is_active", models.BooleanField(db_index=True)),
                ("is_superuser", models.BooleanField(db_index=True)),
                ("created", models.DateTimeField(db_index=True)),
                (
                    "last_access",
                    models.DateTimeField(blank=True, db_index=True, null=True),
                ),
                (
                    "groups",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.CharField(max_length=150),
                        blank=True,
                        default=list,
                        size=None,
                    ),
                ),
            ],
            options={
                "db_table": 'workforce"."customer_all_users',
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="WorkforceAddressSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("tenant", models.CharField(db_index=True, max_length=200)),
                ("last_synced", models.DateTimeField()),
                ("prop_status", models.CharField(blank=True, max_length=30)),
                ("prop_id", models.IntegerField()),
                ("prop_created", models.DateTimeField()),
                (
                    "address",
                    models.CharField(
                        blank=True,
                        help_text="Exact and validated registered postal address.",
                        max_length=1000,
                    ),
                ),
                (
                    "display",
                    models.TextField(
                        help_text="Address that will be used for display purposes.",
                        max_length=1000,
                    ),
                ),
                (
                    "country",
                    models.CharField(
                        blank=True,
                        choices=[("AU", "Australia"), ("NZ", "New Zealand")],
                        default="AU",
                        max_length=2,
                    ),
                ),
                ("gnaf_id", models.CharField(blank=True, default="", max_length=30)),
                (
                    "state",
                    models.CharField(
                        blank=True,
                        default="",
                        max_length=50,
                        verbose_name="State or Region",
                    ),
                ),
                (
                    "postal_code",
                    models.CharField(
                        blank=True,
                        default="",
                        max_length=15,
                        verbose_name="Postal or Zip code",
                    ),
                ),
                ("coords", models.CharField(blank=True, max_length=40)),
            ],
            options={
                "db_table": 'workforce"."address_summary',
                "default_permissions": (),
            },
        ),
        migrations.AddIndex(
            model_name="usagemetrics",
            index=models.Index(
                fields=["tenant", "count_name", "-as_of"],
                name="usage_metrics_latest_btree",
            ),
        ),
    ]



# Generated by Django 3.2.16 on 2023-01-12 23:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('workforce', '0002_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='constancesetting',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='extensionsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='featureflagsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='onboardingactionrow',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='templatechangerequestsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='usagemetrics',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='usersummaryrow',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='workforceaddresssummary',
            options={'default_permissions': (), 'managed': True},
        ),
    ]



# Generated by Django 3.2.16 on 2023-01-12 23:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptionmanager', '0003_serverusage'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='changesummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='chargesummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='paymentmethodsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='recurringcreditsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='revenueforecastsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='serverusage',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='subscriptionsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='workspacesummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='xerocontactsummary',
            options={'default_permissions': (), 'managed': True},
        ),
        migrations.AlterModelOptions(
            name='xeroinvoicesummary',
            options={'default_permissions': (), 'managed': True},
        ),
    ]



# Generated by Django 4.1.5 on 2023-01-12 03:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("subscriptionmanager", "0002_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="ServerUsage",
            fields=[
                (
                    "tenant",
                    models.CharField(max_length=200, primary_key=True, serialize=False),
                ),
                ("staff_licenses_total", models.IntegerField()),
                ("staff_licenses_used", models.IntegerField()),
                ("staff_licenses_additional", models.IntegerField()),
                ("desk_licenses_used", models.IntegerField()),
                ("field_licenses_used", models.IntegerField()),
                ("contractor_licenses_used", models.IntegerField()),
                ("customer_licenses_used", models.IntegerField()),
                ("api_licenses_used", models.IntegerField()),
                ("reporting_licenses_used", models.IntegerField()),
                ("timesheet_licenses_used", models.IntegerField()),
                ("last_synced", models.DateTimeField()),
                ("for_date", models.DateField()),
            ],
            options={
                "db_table": 'subscriptionmanager"."licensing_usage',
                "default_permissions": (),
            },
        ),
    ]



# Generated by Django 4.1.5 on 2023-01-10 23:16

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.RunSQL("""
        create schema if not exists workforce
        """),
    ]


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['app',
 'uptick_datawarehouse',
 'uptick_datawarehouse.subscriptionmanager',
 'uptick_datawarehouse.subscriptionmanager.migrations',
 'uptick_datawarehouse.superblocks',
 'uptick_datawarehouse.superblocks.migrations',
 'uptick_datawarehouse.vitally',
 'uptick_datawarehouse.vitally.migrations',
 'uptick_datawarehouse.workforce',
 'uptick_datawarehouse.workforce.migrations']

package_data = \
{'': ['*']}

install_requires = \
['dj-database-url>=1.2.0,<2.0.0',
 'django-extensions>=3.2.1,<4.0.0',
 'django>=3,<4',
 'dsnparse>=0.1.15,<0.2.0',
 'psycopg2>=2.9.5,<3.0.0']

setup_kwargs = {
    'name': 'uptick-datawarehouse',
    'version': '0.1.4',
    'description': '',
    'long_description': 'Datawarehousing models.\n',
    'author': 'william chu',
    'author_email': 'william.chu@uptickhq.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
